ConfigBuilder

Struct ConfigBuilder 

pub struct ConfigBuilder { /* private fields */ }
Editable configuration source consisting of normalized config data and explicit resource-resolution state.

Implementations

Source

impl ConfigBuilder

pub fn from_opt_file(config_file: Option<&Path>) -> Result<Self, ConfigError>

pub fn from_file(config_file: &Path) -> Result<Self, ConfigError>

Loads config JSON from a file.

The resulting builder contains the deserialized config data, appends the config’s path field to the resolver if present, and then appends the parent directory of config_file as an additional filesystem root.

pub fn from_bytes(data: &[u8]) -> Result<Self, ConfigError>

Loads config JSON from raw bytes.

The resulting builder contains the deserialized config data and appends the config’s path field to the resolver if present.

pub fn from_embedded() -> Result<Self, ConfigError>

Loads the bundled default config JSON.

This only loads the embedded JSON contents; embedded resources themselves are not enabled unless push_embedded() is called.

pub fn empty() -> Self

pub fn system_dict(self, dict: impl Into<PathBuf>) -> Self

pub fn user_dict(self, dict: impl Into<PathBuf>) -> Self

pub fn character_definition_file(self, path: impl Into<PathBuf>) -> Self

pub fn projection(self, projection: SurfaceProjection) -> Self

pub fn with_resolver(self, resolver: PathResolver) -> Self

pub fn append_resolver(self, other: PathResolver) -> Self

pub fn prepend_resolver(self, other: PathResolver) -> Self

pub fn push_resolver_root(self, path: impl Into<PathBuf>) -> Self

pub fn prepend_resolver_root(self, path: impl Into<PathBuf>) -> Self

pub fn push_embedded(self) -> Self

pub fn fallback_data(self, other: &ConfigBuilder) -> ConfigBuilder

pub fn raw_config(&self) -> &RawConfig

pub fn into_raw_config(self) -> RawConfig

pub fn build(self) -> Config