pub struct StringPointer {
pub length: u32,
pub offset: u32,
}Fields
length: u32length of the string (in utf16 codepoint)
offset: u32offset in the CompactedStrings (in utf16 codepoint)
Implementations
Sourceimpl StringPointer
impl StringPointer
Sourcepub const BASE_LENGTH_BITS: u32 = 5
pub const BASE_LENGTH_BITS: u32 = 5
bit count of the base part
Sourcepub const BASE_LENGTH_OFFSET: u32
pub const BASE_LENGTH_OFFSET: u32
offset to the base part
Sourcepub const MAX_VARIABLE_LENGTH_BITS: u32 = 12
pub const MAX_VARIABLE_LENGTH_BITS: u32 = 12
max bit count of the additional length part (in value) note that its top 1 bit is not stored in byte representation.
Sourcepub const MAX_SIMPLE_LENGTH: u32
pub const MAX_SIMPLE_LENGTH: u32
max string length that can be stored using base part only
Sourcepub const MAX_LENGTH: u32
pub const MAX_LENGTH: u32
max string length that can be stored
pub fn unchecked(length: u32, offset: u32) -> Self
pub fn checked(length: u32, offset: u32) -> SudachiResult<Self>
pub fn encode(&self) -> u32
pub fn decode(encoded: u32) -> Self