pub struct WordRef { /* private fields */ }Expand description
Word reference
Reference which points to a entry in the system or user dictionary. Similar to the WordId but the dict id part is a flag which indicates if it is a system or user word.
Top 4 bit is 0000 - points to the word in the system dictionary. Top 4 bit is 0001 - points to the word in the user dictionary which this wordref is used in.
Implementations
Sourceimpl WordRef
impl WordRef
pub const INVALID: WordRef
Sourcepub fn checked(is_system: bool, entry: u32) -> SudachiResult<WordRef>
pub fn checked(is_system: bool, entry: u32) -> SudachiResult<WordRef>
Create a new WordRef with correctness checking
Sourcepub fn resolve(&self, dict: DictId) -> WordId
pub fn resolve(&self, dict: DictId) -> WordId
Resolve the WordRef with its DictId in the dictionary
Sourcepub fn resolve_raw(raw: u32, dict: DictId) -> u32
pub fn resolve_raw(raw: u32, dict: DictId) -> u32
resolve raw