#[non_exhaustive]pub enum WordInfoError {
EntryIdNotAligned(usize),
FailedToLoadEntrySize(usize),
EntryIdTooLarge(usize),
}Expand description
Errors returned while scanning binary WordInfo entry boundaries.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
EntryIdNotAligned(usize)
WordInfo entry offsets must be aligned because entry ids are derived from them.
FailedToLoadEntrySize(usize)
The scanner could not determine a complete, valid entry size at the offset.
EntryIdTooLarge(usize)
The entry offset cannot be represented as a valid Sudachi entry id.