WordInfoResolver

Trait WordInfoResolver 

pub trait WordInfoResolver: LexiconAccess { }
Data structure needed to resolve references in the WordInfoData. Currently only lexicon set is needed, but it can be extended in the future if needed.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors