pub struct Morpheme<'a, D> { /* private fields */ }Expand description
A morpheme as a part of an analysis result.
Implementations
Sourceimpl<D: DictionaryAccess + Clone> Morpheme<'_, D>
impl<D: DictionaryAccess + Clone> Morpheme<'_, D>
Sourcepub fn split(&self, mode: Mode) -> SudachiResult<MorphemeList<D>>
👎Deprecated since 0.6.1: use split_into
pub fn split(&self, mode: Mode) -> SudachiResult<MorphemeList<D>>
use split_into
Returns new morpheme list splitting the morpheme with given mode.
Sourceimpl<'a, D: DictionaryAccess> Morpheme<'a, D>
impl<'a, D: DictionaryAccess> Morpheme<'a, D>
Sourcepub fn part_of_speech(&self) -> &[String]
pub fn part_of_speech(&self) -> &[String]
Returns the part of speech.
Sourcepub fn begin(&self) -> usize
pub fn begin(&self) -> usize
Returns the begin index in bytes of the morpheme in the original text.
Sourcepub fn end(&self) -> usize
pub fn end(&self) -> usize
Returns the end index in bytes of the morpheme in the original text.
Sourcepub fn begin_c(&self) -> usize
pub fn begin_c(&self) -> usize
Returns the codepoint offset of the morpheme begin in the original text.
Sourcepub fn end_c(&self) -> usize
pub fn end_c(&self) -> usize
Returns the codepoint offset of the morpheme end in the original text.
Sourcepub fn surface(&self) -> Ref<'_, str>
pub fn surface(&self) -> Ref<'_, str>
Returns a substring of the original text which corresponds to the morpheme.
pub fn part_of_speech_id(&self) -> u16
Sourcepub fn dictionary_form(&self) -> &str
pub fn dictionary_form(&self) -> &str
Returns the dictionary form of morpheme.
“Dictionary form” means a word’s lemma and “終止形” in Japanese.
Sourcepub fn dictionary_form_morpheme(&self) -> SudachiResult<MorphemeRef<'_, D>>where
D: Clone,
pub fn dictionary_form_morpheme(&self) -> SudachiResult<MorphemeRef<'_, D>>where
D: Clone,
Returns the morpheme corresponding to this morpheme’s dictionary form.
Sourcepub fn normalized_form(&self) -> &str
pub fn normalized_form(&self) -> &str
Returns the normalized form of morpheme.
This method returns the form normalizing inconsistent spellings and inflected forms.
Sourcepub fn normalized_form_morpheme(&self) -> SudachiResult<MorphemeRef<'_, D>>where
D: Clone,
pub fn normalized_form_morpheme(&self) -> SudachiResult<MorphemeRef<'_, D>>where
D: Clone,
Returns the morpheme corresponding to this morpheme’s normalized form.
Sourcepub fn reading_form(&self) -> &str
pub fn reading_form(&self) -> &str
Returns the reading form of morpheme.
Returns Japanese syllabaries ‘フリガナ’ in katakana.
Sourcepub fn dictionary_id(&self) -> i32
pub fn dictionary_id(&self) -> i32
Returns the dictionary id where the morpheme belongs.
Returns -1 if the morpheme is oov.
pub fn synonym_group_ids(&self) -> &[i32]
pub fn get_word_info(&self) -> &WordInfo
Sourcepub fn split_into(
&self,
mode: Mode,
out: &mut MorphemeList<D>,
) -> SudachiResult<bool>
pub fn split_into( &self, mode: Mode, out: &mut MorphemeList<D>, ) -> SudachiResult<bool>
Splits morpheme and writes sub-morphemes into the provided list. The resulting list is not cleared before that. Returns true if split has produced any elements.
Sourcepub fn total_cost(&self) -> i32
pub fn total_cost(&self) -> i32
Returns total cost from the beginning of the path.