pub struct JapaneseDictionary { /* private fields */ }Implementations
Sourceimpl JapaneseDictionary
impl JapaneseDictionary
Sourcepub fn from_cfg(cfg: &Config) -> SudachiResult<JapaneseDictionary>
pub fn from_cfg(cfg: &Config) -> SudachiResult<JapaneseDictionary>
Creates a dictionary from the specified configuration Dictionaries will be read from disk
Sourcepub fn from_cfg_storage(
cfg: &Config,
storage: SudachiDicData,
) -> SudachiResult<JapaneseDictionary>
pub fn from_cfg_storage( cfg: &Config, storage: SudachiDicData, ) -> SudachiResult<JapaneseDictionary>
Creates a dictionary from the specified configuration and storage
Sourcepub fn from_cfg_storage_with_embedded_chardef(
cfg: &Config,
storage: SudachiDicData,
) -> SudachiResult<JapaneseDictionary>
pub fn from_cfg_storage_with_embedded_chardef( cfg: &Config, storage: SudachiDicData, ) -> SudachiResult<JapaneseDictionary>
Creates a dictionary from the specified configuration and storage, with embedded character definition
Sourcepub fn lexicon(&self) -> &LexiconSet<'_>
pub fn lexicon(&self) -> &LexiconSet<'_>
Returns lexicon with the correct lifetime